@@ -1,7 +1,6 @@
 """Module with datetime core utils."""
 
 import datetime
-import zoneinfo
 
 
 def get_utc_now() -> datetime.datetime:
@@ -11,4 +10,4 @@ def get_utc_now() -> datetime.datetime:
     -------
         datetime: current datetime with UTC timezone.
     """
-    return datetime.datetime.now(zoneinfo.ZoneInfo("UTC"))
+    return datetime.datetime.now(datetime.UTC)
